@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2021-2022 Constantine Evans <const@costi.eu>
+#
+# SPDX-License-Identifier: AGPL-3.0-only
+
 from __future__ import annotations
 
 import re
@@ -9,7 +13,7 @@ from typing import Any, Callable, ClassVar, Dict, Tuple, Type, TypeVar, TYPE_CHE
 
 T = TypeVar("T", bound="BaseStatus")
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from .machine import Machine
 
 
